@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2019/02/20 21:02:15 $
- * $Revision: 1.221 $
+ * $Date: 2021/08/25 23:34:40 $
+ * $Revision: 1.225 $
  */
 
 #define L_MARKER '<'
@@ -666,6 +666,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 			}
 			break;
 		     case 'A':
+#if !(defined(__hpux) && !defined(NCURSES_VERSION))
 			switch (string[from + 1])
 			{
 			case 'L':
@@ -681,6 +682,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 			   lastChar = ACS_DARROW;
 			   break;
 			}
+#endif
 			break;
 		     default:
 #if 0
@@ -691,6 +693,7 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 				       + (string[from + 2] - '0'));
 			else
 #endif
+#if !(defined(__hpux) && !defined(NCURSES_VERSION))
 			   if (string[from + 1] == 'D' &&
 			       string[from + 2] == 'I')
 			   lastChar = ACS_DIAMOND;
@@ -712,6 +715,8 @@ chtype *char2Chtype (const char *string, int *to, int *align)
 			else if (string[from + 1] == 'S' &&
 				 string[from + 2] == '9')
 			   lastChar = ACS_S9;
+#endif
+			break;
 		     }
 
 		     if (lastChar != 0)
@@ -886,9 +891,9 @@ char *chtype2String (const chtype *string)
 
 	 for (x = 0; x < len; ++x)
 	 {
-	    unsigned this_ch = string[x];
-	    unsigned last_ch = (x > 0) ? string[x - 1] : 0;
-	    int next = ((this_ch & 0xff) < 32) ? 5 : 1;
+	    chtype this_ch = string[x];
+	    chtype last_ch = (x > 0) ? string[x - 1] : 0;
+	    unsigned next = ((this_ch & 0xff) < 32) ? 5 : 1;
 
 	    need = decodeAttribute (newstring, need, last_ch, this_ch);
 	    if (newstring != 0)
@@ -902,8 +907,8 @@ char *chtype2String (const chtype *string)
 		  unsigned ch = (0xff & this_ch);
 		  newstring[need] = L_MARKER;
 		  newstring[need + 1] = '#';
-		  newstring[need + 2] = '0' + (ch / 10);
-		  newstring[need + 3] = '0' + (ch % 10);
+		  newstring[need + 2] = (char)('0' + (ch / 10));
+		  newstring[need + 3] = (char)('0' + (ch % 10));
 		  newstring[need + 4] = R_MARKER;
 
 	       }
@@ -1176,7 +1181,6 @@ int mode2Char (char *string, mode_t mode)
    };
    /* *INDENT-ON* */
 
-   /* Declare local variables.  */
    int permissions = 0;
    int filetype = mode2Filetype (mode);
    unsigned n;
